/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.glite.apel.publisher;

import java.util.concurrent.TimeoutException;
import javax.jms.Destination;
import javax.jms.DeliveryMode;
import javax.jms.JMSException;
import javax.jms.Queue;
import javax.jms.QueueConnection;
import javax.jms.QueueConnectionFactory;
import javax.jms.QueueSession;
import javax.jms.Message;
import javax.jms.MessageConsumer;
import javax.jms.MessageProducer;
import javax.jms.TextMessage;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import org.glite.apel.core.ApelException;
import org.glite.apel.core.config.parser.Config;
import org.apache.log4j.Logger;
import org.glite.apel.core.db.ApelDB;

public class AccountChecker {
    // Timeout for received message queue

    private static long m_timeout = 1800000;
    private Config m_config = null;
    private Logger m_log = Logger.getLogger(getClass().getName());

    AccountChecker(Config apelConfig) {
        m_config = apelConfig;
        // Retrieve a timeout from the configuration file
        m_timeout = Long.parseLong(
                m_config.getProperty(PublisherMap.PROP_CONSUMER_REPLY_TIMEOUT));
    }

    public int execute(String message, String siteName)
            throws ApelException {
        QueueConnection m_queueConnection = null;
        QueueSession m_queueSession = null;
        MessageProducer m_producer = null;

        String messageText = null;
        try {
            javax.naming.Context ctx = new InitialContext();

            //lookup the connection factory

            QueueConnectionFactory queueConnectionFactory = (QueueConnectionFactory) ctx.lookup("QueueConnectionFactory");                // lookup an existing  queue

            Queue m_queue = (Queue) ctx.lookup("grid.accounting.apel.cpujobs.individualjobs.check");

            // create a new Connection for pub messaging

            m_queueConnection = queueConnectionFactory.createQueueConnection();

            // create a new QueueSession for the client

            m_queueSession = m_queueConnection.createQueueSession(false, QueueSession.AUTO_ACKNOWLEDGE);

            m_producer = m_queueSession.createProducer(m_queue);
            m_producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
            m_queueConnection.start();

            Destination tempDest = m_queueSession.createTemporaryQueue();
            MessageConsumer responseConsumer = m_queueSession.createConsumer(tempDest);

            TextMessage txtMessage = m_queueSession.createTextMessage();
            txtMessage.setText(message);

            txtMessage.setStringProperty("apel_record_type", "apel_site_query");
            txtMessage.setJMSReplyTo(tempDest);
            txtMessage.setJMSCorrelationID(siteName);

            m_producer.send(txtMessage);
            Message incomeMesg = responseConsumer.receive(m_timeout);

            if (incomeMesg == null) {
                throw new TimeoutException("APEL Consumer did not respond to "
                        + "a request for confirmation of pre-published data."
                        + " Please contact APEL Support Staff.");
            }
            TextMessage textMessage = (TextMessage) incomeMesg;
            messageText = textMessage.getText();

        } catch (NamingException e) {
            System.out.println("Caught: " + e);
            e.printStackTrace();
            System.out.println("Caught: " + e);
        } catch (JMSException e) {
            System.out.println("Caught: " + e);
            e.printStackTrace();
        } catch (TimeoutException e) {
            throw new ApelException(e);
        } finally {
            try {
                m_producer.close();
                m_queueSession.close();
                m_queueConnection.close();
            } catch (JMSException e) {
                throw new ApelException(e);
            }
        }
        return Integer.parseInt(messageText);
    }

    /**
     * Returns the number of archived tuples beginning from the date/time.
     * Returns -1 if the query cannot complete if the goc archiver is
     * unavailable.
     */
    public int countArchivedRecords(String date, String time, String siteName)
            throws ApelException {
        return execute("SELECT COUNT(*) FROM " + ApelDB.LCG_RECORDS_TABLE_NAME
                + " WHERE ((MeasurementDate = '" + date
                + "' AND MeasurementTime >= '" + time + "') OR "
                + "MeasurementDate > '" + date + "') AND ExecutingSite = '"
                + siteName + "'", siteName);

    }
}
