/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.publisher;

import org.glite.apel.core.db.ApelDB;

/**
 * Contains a list of user error/warning codes used by the join processor.
 */
class LogMsgs {
    
    /**
     * Error message printed when GOC secondary producer is unavailable.  
     */
    static final String GOC_UNAVAILABLE = "Received a 'null' result set " +
        "while querying the '" + ApelDB.LCG_RECORDS_TABLE_NAME + 
        "' table using rgma, this probably means the GOC is currently " +
        "off-line, will therefore cancel attempt to re-publish";
    
    /**
     * Warning messaged printed when the GOC and local db's do not 
     * match up.
     */
    static final String DETECTED_MISSING_RECORDS =  
        "Detected missing records, republishing data starting from: ";
    
    /**
     * Warning message printed if the user has deleted records locally
     * (meaning the GOC and local db cannot be synchronized).
     */
    static final String UNABLE_TO_SYNCHRONIZE = "Cannot synchronize: local " +
	    "database contains fewer records compared to the GOC database";
    
    /**
     * Message printed if the last start time cannot be found within
     * republish info table.
     */
    static final String CANNOT_FIND_LAST_START_TIME = 
        "Time stamp when the apel was last started cannot be found, " +
        "this probably means APEL is running for the first time with the " +
        "re-publish option set to 'missing', re-publishing check will " +
        "therefore occur on next attempt";
    
    /**
     * Warning message printed if no spec has been defined (but
     * reprocess flag has been set).
     */
    static final String NO_SPEC_DEFINED_WITH_REPROCESS = 
        "No CPU spec values defined, currently detected re-process option " +
        "so this means existing data found in the table '" + 
        ApelDB.LCG_RECORDS_TABLE_NAME + 
        "' will only be re-published (new accounting records can " +
        "not be generated without a CPU Spec value), check user " +
        "documentation for more help";  
    
    /**
     * Error message set if no spec has been defined in the db 
     * (and reprocess flag has not been set).
     */
    static final String NO_SPEC_DEFINED_IN_DB = "Cannot generate any " +
        "accounting records because no cpu spec value is defined in the " + 
        ApelDB.SPEC_TABLE_NAME + " table, spec values are added when " +
        "running the CPUProcessor, check user documentation for more help";
    
}
