/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.publisher;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;

import org.glite.apel.core.ApelException;
import org.glite.apel.core.db.ApelDB;
import org.glite.apel.core.db.MySQLImpl;
import org.glite.apel.core.log.type.AccountRecordIterator;

import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * System tests which validate the funcationality of the AccountPublisher
 * component.
 */
public class AccountPublisherTest extends TestCase {
    
    /**
     * Database connection to the accounting database.
     */
    private Connection m_connection;
    
    /**
     * Site name used for this test.
     */
    private String m_siteName;
    
    /**
     * Url to the accounting database.
     */
    private String m_db;
    
    /**
     * DB username.
     */
    private String m_user;
    
    /**
     * password for the user.
     */
    private String m_pass;
    
    public static junit.framework.Test suite() {
        return new TestSuite(AccountPublisherTest.class);
    }
    
    public void setUp() {
        m_db = "jdbc:mysql://localhost/test";
        m_user = "test";
        m_pass = "info";
        String driver = "org.gjt.mm.mysql.Driver";
        m_siteName = "Example-Test";
        try {
            Class.forName(driver);
            m_connection = DriverManager.getConnection(m_db, m_user, m_pass);
        } catch (Exception e) {
            e.printStackTrace();
            fail();
        }
    }

    public void tearDown() {
        deleteRecords();
        close(m_connection);
    }
    
    /**
     * Scrubs all the tables used by the Apel program.
     */
    private void deleteRecords() {
        Statement stmt = null;
        try {
            stmt = m_connection.createStatement();
            stmt.executeUpdate("DELETE FROM " + ApelDB.REPUBLISH_TABLE_NAME);
            stmt.executeUpdate("DELETE FROM " + ApelDB.MSG_TABLE_NAME);
            stmt.executeUpdate("DELETE FROM " + ApelDB.GK_TABLE_NAME);
            stmt.executeUpdate("DELETE FROM " + ApelDB.SPEC_TABLE_NAME);
            stmt.executeUpdate("DELETE FROM " + ApelDB.EVENT_TABLE_NAME);
            stmt.executeUpdate("DELETE FROM " + ApelDB.LCG_RECORDS_TABLE_NAME);
            stmt.executeUpdate("DELETE FROM " + ApelDB.PROCESSED_FILES_TABLE_NAME);
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            close(stmt);
        }
    }
    
    /**
     * Tests a result set derived from the accounting table can
     * be published into rgma (test is rather basic, but don't want
     * to get bogged down testing rgma specific stuff here).
     */
    public void testAdd() {
        insertJunk();
        try {
            AccountPublisher publisher = new AccountPublisher(false);
            MySQLImpl mysql = new MySQLImpl(m_db, m_user, m_pass, m_siteName);
            AccountRecordIterator it = mysql.getAllAccountingRecords();
            assertTrue(it.hasNext());
          	publisher.publish(it);
        } catch (ApelException e) {
        	e.printStackTrace();
            fail();
        }
    }
    
    /**
     * Inserts a dummy record into the LcgRecords table.
     */
    private void insertJunk() {
        Statement stmt = null;
        try {
            stmt = m_connection.createStatement();
            stmt.execute("INSERT INTO " + ApelDB.LCG_RECORDS_TABLE_NAME + 
                " VALUES ('TEST','" + m_siteName + "','','','','','','','', " +
                "0, 0, '', '', '', '', 0, 0, '', 0, 0, 0, 0, '', '', " + 
                "'2005-01-01', '00:00:00')");
        } catch (SQLException e) {
            e.printStackTrace();
            fail();
        }
    }

    /**
     * Closes an sql Connection, catching any exceptions that are thrown.
     */
    void close(Connection conn) {
        try {
            conn.close();
        } catch (Exception e) {}
    }
    
    /**
     * Closes an sql Statement, catching any exceptions that are thrown.
     */
    void close(Statement stmt) {
        try {
            stmt.close();
        } catch (Exception e) {}
    }
    
}
