#!/bin/sh
#
# Copyright (c) Members of the EGEE Collaboration. 2004-2010.
# See http://www.eu-egee.org/partners/ for details on the
# copyright holders. 
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
# either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

search() {
    grep "$1" $LOG >> /dev/null
    if [ $? != 0 ]; then
		echo
		echo ++++++++ TEST FAILURE searching for \"$1\" ++++++++
    else
    	echo
		echo "******* Test Passed *******"    
    fi
	FAIL=1
}

if [ $# != 3 ]; then
	echo
	echo "usage $0 [mysql-db-name] [user-name] [password]"
	echo
	exit 1
fi

if [ -z $APEL_HOME ]; then
  echo
  echo "APEL_HOME is not set"
  exit 1
fi

LOG=test-output.log
MYSQL_DB="$1"
MYSQL_USER="$2"
MYSQL_PSWD="$3"

if [ -f $LOG ]; then
    rm $LOG
fi

touch $LOG

PROG_BIN="$APEL_HOME/bin/apel-publisher.sh"
CONFIG="`pwd`/config"

echo
echo "Deleting database contents"
echo

echo "$PROG_BIN -f $CONFIG/delete-all.xml"
$PROG_BIN -f $CONFIG/delete-all.xml >> /dev/null 2>&1

echo
echo "************* Running Test *************"
echo
echo "Using empty db, checking no accounting records are generated "
echo
echo "$PROG_BIN -f $CONFIG/join-all.xml"
$PROG_BIN -f $CONFIG/join-all.xml >> $LOG 2>&1

search 'Number of generated accounting records: 0'
echo
echo "Log output from previous test"
echo
cat $LOG
cat /dev/null > $LOG

echo
echo "Populating database with sample parsed data"

mysql -u $MYSQL_USER -p$MYSQL_PSWD $MYSQL_DB < $CONFIG/db-sample.txt

echo
echo "************* Running Test *************"
echo
echo "Regenerating accounting records, testing correct number records produced"
echo
echo "$PROG_BIN -f $CONFIG/join-all.xml"
$PROG_BIN -f $CONFIG/join-all.xml >> $LOG 2>&1

search 'Number of generated accounting records: 170'
echo
echo "Log output from previous test"
echo
cat $LOG
cat /dev/null > $LOG

echo
echo "Populating database with more sample parsed data"

mysql -u $MYSQL_USER -p$MYSQL_PSWD $MYSQL_DB < $CONFIG/db-sample2.txt

echo
echo "************* Running Test *************"
echo
echo "Republish-all disabled, checking only new records are published"
echo
echo "$PROG_BIN -f $CONFIG/join-new.xml"
$PROG_BIN -f $CONFIG/join-new.xml >> $LOG 2>&1

search 'Number of generated accounting records: 170'
echo
echo "Log output from previous test:"
echo
cat $LOG
cat /dev/null > $LOG


echo
echo "************* Running Test *************"
echo
echo "Regenerating accounting records, testing correct number records produced"
echo
echo "$PROG_BIN -f $CONFIG/join-all.xml"
$PROG_BIN -f $CONFIG/join-all.xml >> $LOG 2>&1

search 'Number of generated accounting records: 340'
echo
echo "Log output from previous test:"
echo
cat $LOG


